@@ -304,22 +304,18 @@ class URLTarget(object):
             last_modified (str, optional): The last_modified header from the Webpage. Defaults to None.
         """
 
-        if last_modified is not None:
-            filetime = timeconvert(last_modified)
-            if filetime is not None and filetime >= 0:
-                try:
+        try:
+            if last_modified is not None:
+                filetime = timeconvert(last_modified)
+                if filetime is not None and filetime > 0:
                     os.utime(self.file.saved_to, (time.time(), filetime))
                     return
-                except Exception:
-                    logging.debug('T%s - Could not change utime', self.thread_id)
-                    pass
 
-        try:
-            os.utime(self.file.saved_to, (time.time(), self.file.content_timemodified))
-            return
+            if self.file.content_timemodified is not None and self.file.content_timemodified > 0:
+                os.utime(self.file.saved_to, (time.time(), self.file.content_timemodified))
+
         except Exception:
             logging.debug('T%s - Could not change utime', self.thread_id)
-            pass
 
     def try_download_link(
         self, add_token: bool = False, delete_if_successful: bool = False, use_cookies: bool = False
@@ -344,10 +340,9 @@ class URLTarget(object):
         if add_token:
             url_to_download = self._add_token_to_url(self.file.content_fileurl)
 
-        cookies_path = None
+        cookies_path = self.options.get('cookies_path', None)
         if use_cookies:
-            cookies_path = self.options.get('cookies_path', None)
-            if cookies_path is None:
+            if cookies_path is None or not os.path.isfile(cookies_path):
                 self.success = False
                 raise ValueError(
                     'Moodle Cookies are missing. Run `moodle-dl -nt` to set a privatetoken for cookie generation (If necessary additionally `-sso`)'
@@ -370,11 +365,10 @@ class URLTarget(object):
         total_bytes_estimate = -1
         session = requests.Session()
 
-        if use_cookies:
-            session.cookies = MozillaCookieJar(cookies_path)
+        session.cookies = MozillaCookieJar(cookies_path)
 
-            if os.path.exists(cookies_path):
-                session.cookies.load(ignore_discard=True, ignore_expires=True)
+        if os.path.isfile(cookies_path):
+            session.cookies.load(ignore_discard=True, ignore_expires=True)
 
         try:
             response = session.head(
@@ -439,27 +433,29 @@ class URLTarget(object):
                 'ignoreerrors': True,
                 'addmetadata': True,
             }
+
             youtube_dl_options = self.options.get('youtube_dl_options', {})
             ydl_opts.update(youtube_dl_options)
 
-            if use_cookies:
+            if cookies_path is not None and os.path.isfile(cookies_path):
                 ydl_opts.update({'cookiefile': cookies_path})
 
-            with youtube_dl.YoutubeDL(ydl_opts) as ydl:
-                try:
-                    ydl_results = ydl.download([url_to_download])
-                    if ydl_results == 1:
-                        # return False
-                        pass
-                    elif self.file.module_name != 'index_mod-page':
-                        self.file.saved_to = str(Path(self.destination) / self.filename)
-                        self.file.time_stamp = int(time.time())
-
-                        self.success = True
-                        return True
-                except Exception:
+            ydl = youtube_dl.YoutubeDL(ydl_opts)
+            try:
+                ydl_results = ydl.download([url_to_download])
+                if ydl_results == 1:
                     # return False
                     pass
+                elif self.file.module_name != 'index_mod-page':
+                    self.file.saved_to = str(Path(self.destination) / self.filename)
+                    self.file.time_stamp = int(time.time())
+
+                    self.success = True
+                    return True
+            except Exception:
+                # return False
+                pass
+            # if we want we could save ydl.cookiejar (Also the cookiejar of moodle-dl)
 
             if self.youtube_dl_failed_with_error is True:
                 if not delete_if_successful:
@@ -706,10 +702,8 @@ class URLTarget(object):
                 self.try_download_link(add_token, True, False)
                 return self.success
 
-            cookies_path = None
             if self.file.module_modname.startswith('cookie_mod'):
                 add_token = False
-                cookies_path = self.options.get('cookies_path', None)
                 self.try_download_link(add_token, True, True)
                 return self.success
 
@@ -728,6 +722,8 @@ class URLTarget(object):
             if add_token:
                 url_to_download = self._add_token_to_url(self.file.content_fileurl)
 
+            cookies_path = self.options.get('cookies_path', None)
+
             self.urlretrieve(
                 url_to_download,
                 self.file.saved_to,
@@ -785,8 +781,9 @@ class URLTarget(object):
         request = urllib.request.Request(url=url, headers=RequestHelper.stdHeader)
         if cookies_path is not None:
             cookie_jar = MozillaCookieJar(cookies_path)
-            cookie_jar.load(ignore_discard=True, ignore_expires=True)
-            cookie_jar.add_cookie_header(request)
+            if os.path.isfile(cookies_path):
+                cookie_jar.load(ignore_discard=True, ignore_expires=True)
+                cookie_jar.add_cookie_header(request)
 
         with contextlib.closing(urllib.request.urlopen(request, context=context)) as fp:
             headers = fp.info()
